/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.ui.*;
import danger.audio.Tone;
import danger.audio.ToneFilter;
import danger.app.Application;
import danger.app.Event;
import danger.app.ResourceDatabase;
import danger.app.EventType;
import danger.util.DEBUG;

/**
 * Created by IntelliJ IDEA.
 * User: Jake
 * Date: Dec 13, 2003
 * Time: 8:11:40 PM
 * To change this template use Options | File Templates.
 */
public class AddToneDialog extends DialogWindow implements Resources, Commands {

    static public class AddToneCustomTextField extends TextField {
        AddToneDialog mATDialog;

        public void loseFocus() {
            String text = toString().toLowerCase();
            if (text.endsWith(".mid") ||
                text.endsWith(".midi") ||
                text.endsWith(".rmf"))
            mATDialog._sldTempo.enable();
            else
            mATDialog._sldTempo.disable();
            super.loseFocus();

        }
    }

    Event     _event;
    AddToneCustomTextField _txtURL;
    TextField _txtName;
    Slider    _sldVolume;
    Slider    _sldPriority;
    Slider    _sldTempo;
    CheckBox  _chkLoop;
    CheckBox  _chkFlash;
    CheckBox  _chkVibrate;
    ToneProperties _toneProperties;

    public AddToneDialog() {
        //default constructor needed
    }

    public void onDecoded() {

        _toneProperties = new ToneProperties();

        _txtURL = (AddToneCustomTextField)this.getChildWithID(txtATURL);
        _txtName = (TextField)this.getChildWithID(txtATName);
        _sldVolume = (Slider)this.getChildWithID(sldATVolume);
        _sldPriority = (Slider)this.getChildWithID(sldATPriority);
        _sldTempo = (Slider)this.getChildWithID(sldATTempo);
        _chkLoop = (CheckBox)this.getChildWithID(chkATLoop);
        _chkFlash = (CheckBox)this.getChildWithID(chkATFlash);
        _chkVibrate = (CheckBox)this.getChildWithID(chkATVibrate);

        _txtURL.mATDialog=this;

        ResourceDatabase rsrc = Application.getCurrentApp().getResources();
        Bitmap[] volumeIcons = rsrc.getBitmapArray(bmpsVolume);
        Bitmap[] speedIcons = rsrc.getBitmapArray(bmpsSpeed);
        Bitmap[] priorityIcons = rsrc.getBitmapArray(bmpsPriority);

        _sldVolume.setBitmaps(volumeIcons);
        _sldVolume.setSliderType(Slider.COMPRESSED);
        _sldVolume.setTitleSpacing(0);
        _sldVolume.setWidth(100);

        _sldPriority.setBitmaps(priorityIcons);
        _sldPriority.setSliderType(Slider.COMPRESSED);
        _sldPriority.setTitleSpacing(0);
        _sldPriority.setWidth(100);

        _sldTempo.setBitmaps(speedIcons);
        _sldTempo.setSliderType(Slider.COMPRESSED);
        _sldTempo.setTitleSpacing(0);
        _sldTempo.setWidth(100);

        //no default name or url
        _sldVolume.setValue(_toneProperties._volume);
        _sldPriority.setValue(_toneProperties._priority);
        _sldTempo.setValue(_toneProperties._tempo);

        _chkLoop.setValue(_toneProperties._loop?1:0);
        _chkFlash.setValue(((_toneProperties._filter & ToneFilter.FLASHER) != 0)?1:0);
        _chkVibrate.setValue(((_toneProperties._filter & ToneFilter.BUZZER) != 0)?1:0);
    }

    public boolean receiveEvent(Event event) {
        boolean handled = false;
        switch (event.type) {
            case evtATDone:
                _toneProperties._url = _txtURL.toString();
                _toneProperties._name = _txtName.toString();
                _toneProperties._volume = _sldVolume.getValue();
                _toneProperties._priority = _sldPriority.getValue();
                _toneProperties._tempo = _sldTempo.getValue();
                _toneProperties._loop = (_chkLoop.getValue() == 1);

                _toneProperties._filter = ToneFilter.SOUND;
                if (_chkVibrate.getValue()==1)
                    _toneProperties._filter += ToneFilter.BUZZER;
                if (_chkFlash.getValue()==1)
                    _toneProperties._filter += ToneFilter.FLASHER;

                _event.argument = _toneProperties;
                _event.sendToTarget();
                break;
        }
        return handled | super.receiveEvent(event);
    }


    public void hide() {
        DEBUG.p("I am hidden");
        super.hide();
    }

    public static AddToneDialog newAddToneDialog(Event evt) {
        AddToneDialog dialog = (AddToneDialog)Application.getCurrentApp().getResources().getDialog(dlgAddTone);
        dialog._event = evt;
        return dialog;
    }
}
