/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;


// Import statements.  Add any other packages you might need:
// import danger.audio.*;
// import danger.crypto.*;
// import danger.net.*;
// import danger.util.*;
import danger.app.*;
import danger.ui.*;
import danger.util.DEBUG;
import danger.util.Folder;
import danger.audio.ToneGallery;
import danger.audio.Meta;
import danger.audio.Tone;
import danger.audio.ToneClass;
import danger.net.HTTPConnection;

// This is is an example of a Window class. You probably want to rename
// this class.  Don't forget to change the constructor name, as well as
// the file name of this source code file.
public class MainWindow extends ScreenWindow implements Resources, Commands, AppEvents {

    private MetaFolderView _metaList;
    private Penfold _app;

	public MainWindow() {

		//Constructor
        _app = (Penfold)this.getApplication();
        setIcon(_app.getBundle().getSmallIcon());

	}

    public void onDecoded() {
        _metaList = (MetaFolderView)this.getChildWithID(mfvMetaList);
    }

    public boolean eventShortcut(char c, Event event) {
        if (c=='N') { // && event.modifierIsActive(EventType.DEVICE_META_CAPS)) {
            AlertWindow a = _app.getAlert(alrtHardSoundReset, this);
            a.show();
        }
        return super.eventShortcut(c, event);
    }

    public boolean eventWidgetDown(int i, Event event) {
        boolean handled = false;

        switch (event.what) {
            case EventType.DEVICE_BUTTON_BACK:
                _app.returnToLauncher();
                break;

            case EventType.DEVICE_BUTTON_MENU:
                // determine which menu items should be shown
                //MenuItem previewMenu = this.getActionMenu().getItem(mnuMainPreview);
                //MenuItem assignMenu = this.getActionMenu().getItem(mnuMainAssign);
                Menu menu = this.getActionMenu();
                ResourceDatabase rsrc = _app.getResources();
                menu.removeAllItems();
                if (_metaList.getSelection() instanceof Folder) {
                    ////we have a folder
                    //previewMenu.setEnabled(false);
                    //assignMenu.setEnabled(false);
                    menu.addFromResource(rsrc, mnuMainFolder, this);
                } else {
                    menu.addFromResource(rsrc, mnuMainMeta, this);
                }
                handled = false;
                break;
        }

        return handled | super.eventWidgetDown(i, event);
    }

    public boolean receiveEvent(Event event) {
        boolean handled = false;
        Object selected = _metaList.getSelection();
        switch (event.type) {
            case evtMyTones:
                _app.tonesWindow.show();
                break;

            case evtAssignTone:
                if (selected instanceof MetaObject) {
                    if (_app.tonesWindow.getToneCount() > 0) {
                        Event evt = new Event(this, evtDoAssignment);
                        ToneSelectDialog dialog = ToneSelectDialog.newToneSelectDialog(evt, _app.getTonesList());
                        dialog.show();
                    } else {
                        AlertWindow w = new AlertWindow("No Tones Available", "Please go to MyTones (\uF007T) to add tones to your collection.");
                        w.show();
                    }
                }
                break;

            case evtDoAssignment:
                if (selected instanceof MetaObject) {
                    Tone tone = (Tone)event.argument;
                    int metaID = ((MetaObject)selected).getMetaID();
                    if (tone != null) {
                        DEBUG.p("Setting " + metaID + " to " + tone.getName());
                        boolean resp = Meta.setToneToID(tone, metaID);
                        DEBUG.p("Resonse to setting tone: " + resp);
                        //Meta.unmuteID(metaID);
                    } else {
                        DEBUG.p("No tone selected.  Resetting");
                        Meta.restoreIDToDefault(metaID);
                    }
                }
                break;

            case evtPreviewMeta:
                if (selected instanceof MetaObject) {
                    Tone toPreview = Meta.getToneFromID(((MetaObject)selected).getMetaID());
                    //TonePreviewDialog tpd = TonePreviewDialog.newTonePreviewDialog(toPreview);
                    //tpd.show();
                    _app.previewTone(toPreview);
                }
                break;

            case evtMetaProperties:
                if (selected instanceof MetaObject)  {
                    int metaID = ((MetaObject)selected).getMetaID();
                    MetaPropertiesDialog dlg = MetaPropertiesDialog.newMetaPropertiesDialog(metaID);
                    dlg.show();
                }
                break;

            case evtResetSounds:
                MetaMeta.resetMetas();
                break;

            case evtAlertHardSoundResetYes:
                try {
                    MetaMeta.resetMetas();
                    _app.clearAllMyTones();
                    ToneGallery.removeAllStored();
                    Meta.play(Meta.DELETE_TRASH);
                    AlertWindow a = new AlertWindow("All sounds reset!", "All 'MyTones' and ringtones cleared!", false);
                    a.show();
                } catch (Exception e) {
                    AlertWindow a = new AlertWindow("Error", "Unable to reset 'MyTones' and ringtones!", false);
                    a.show();
                }
                break;

            case evtAbout:
                _app.showAbout();
                break;
        }


        return handled | super.receiveEvent(event);
    }


}