/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.ui.*;
import danger.util.Folder;
import danger.util.StringUtils;
import danger.util.DEBUG;
import danger.app.Application;


public class MetaFolderView extends FolderView implements Resources {

    private Bitmap[] volumeIcons;
    private final static int VOLUME_ICON_WIDTH = 20;

    public MetaFolderView() {
        //default constructor
    }

    public void onDecoded() {
        // add folders from MetaMeta
        for (int x=0; x<MetaMeta.getFolders().length; x++)
            this.addFolder(new Folder(MetaMeta.getFolders()[x]));

        for (int x=0; x<MetaMeta.getMetaCount(); x++) {
            MetaObject obj = new MetaObject(MetaMeta.getMetaID(x));
            Folder folder = this.getFolder(MetaMeta.getFolderFromIndex(x));
            folder.addItem(obj);
        }

        volumeIcons = Application.getCurrentApp().getResources().getBitmapArray(bmpsVolume);
    }

    protected void drawFolderLine(Pen pen, Object o, Rect rect, boolean b) {
        Folder  folderToDraw = (Folder)o;
        int textPos = folderToDraw.getOpenIcon().getWidth() + COLUMN_GAP;
        int offset  = rect.left + textPos;

        String  title = folderToDraw.getTitle();
        int             numItemsInFolder = folderToDraw.size();

        title += " (" + numItemsInFolder + ")";

        title = StringUtils.truncate(title, rect.right - offset, mFontBold, StringUtils.TRUNCATE_AT_END);

        pen.setFont(mFontBold);
        pen.drawText(offset, rect.top + mAscent, title);

        if (folderToDraw.isOpen())
            pen.drawBitmap(rect.left, rect.top + 1, folderToDraw.getOpenIcon());
        else
            pen.drawBitmap(rect.left, rect.top + 1, folderToDraw.getClosedIcon());
    }

    protected void drawItemLine(Pen pen, Object o, Rect rect, boolean b) {
        MetaObject obj = (MetaObject)o;
        String    text;
        text = obj.getName();

        pen.setFont(mFontPlain);

        text = StringUtils.makeDisplayString(text, rect.getWidth(), mFontPlain);

        int vol = obj.getVolume();

        Bitmap toDraw = null;
        if (obj.isMuted() || vol == 0)
            toDraw = volumeIcons[0];
        else
            toDraw = volumeIcons[(vol/50)+1];

        final int indent = 10;
        pen.drawBitmap(rect.left+indent, rect.top + 1, toDraw);

        //gray out the text if there is no sound assigned to Meta.
        if (!obj.isAssigned())
            pen.setColor(Color.GRAY4);

        pen.drawText(rect.left + indent + VOLUME_ICON_WIDTH + 2, rect.top + mAscent, text);

    }
}
