/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.audio.Meta;
import danger.audio.Tone;
import danger.app.Application;

import java.util.Vector;

/*
*   This class encapsulates an entire sound scheme
*/
public class MetaMeta implements Resources {

    private static String[] metaNames;
    private static String[] folderNames;
    private static int[]    defaultMetaRsrcIDs;

    public static void initalize() {
        Application app = Application.getCurrentApp();
        metaNames = app.getResources().getStringArray(strsMetaLabels);
        folderNames = app.getResources().getStringArray(strsMetaFolders);

        resetMetas();
        defaultMetaRsrcIDs = new int[metas.length];
        for (int x=0; x<metas.length; x++) {
            Tone tone = Meta.getToneFromID(metas[x]);

            if (tone == null)
                defaultMetaRsrcIDs[x] = 0;
            else
                defaultMetaRsrcIDs[x] = tone.getResourceID();
        }
    }

    public static void resetMetas() {
        for (int x=0; x<metas.length; x++)
             Meta.restoreIDToDefault(metas[x]);
    }

    public static int getMetaCount() {
        return metas.length;
    }

    public static int getIndex(int metaID) {
        for (int x=0; x<metas.length; x++)
            if (metas[x] == metaID)
                return x;
        return -1;
    }

    public static int getMetaID(int ndx) {
        return metas[ndx];
    }

    public static String getFolderFromIndex(int ndx) {
        return folderNames[metaFolderIndex[ndx]];
    }

    public static String getName(int metaID) {
        return metaNames[getIndex(metaID)];
    }

    public static String[] getFolders() {
        return folderNames;
    }

    public static String getFolder(int metaID) {
        return folderNames[metaFolderIndex[getIndex(metaID)]];
    }

    private static final int[] metas = {Meta.BEEP_COMMAND_ACCECPTED,
                                       Meta.BEEP_COMMAND_REJECTED,
                                       Meta.BEEP_ACTION_SUCCESS,
                                       Meta.BEEP_ACTION_FAIL,
                                       Meta.BEEP_STARTUP_SOUND,
                                       Meta.SCROLL_LIMIT,
                                       Meta.SCROLL_WHEEL_UP,
                                       Meta.SCROLL_WHEEL_DOWN,
                                       Meta.FEEDBACK_WHEEL_BUTTON,
                                       Meta.FEEDBACK_MENU_BUTTON,
                                       Meta.FEEDBACK_JUMP_BUTTON,
                                       Meta.FEEDBACK_BACK_BUTTON,
                                       Meta.FEEDBACK_KEY_ONCE,
                                       Meta.FEEDBACK_KEY_REPEAT,
                                       Meta.FEEDBACK_DELETE_KEY_ONCE,
                                       Meta.FEEDBACK_DELETE_KEY_REPEAT,
                                       Meta.FEEDBACK_RETURN_KEY_ONCE,
                                       Meta.FEEDBACK_RETURN_KEY_REPEAT,
                                       Meta.FEEDBACK_SPACE_KEY_ONCE,
                                       Meta.FEEDBACK_SPACE_KEY_REPEAT,
                                       Meta.FEEDBACK_PAGE_UP,
                                       Meta.FEEDBACK_PAGE_DOWN,
                                       Meta.FEEDBACK_AUTO_REPLACE,
                                       Meta.FEEDBACK_AUTO_CAP,
                                       Meta.FEEDBACK_PROFILE_VOL,
                                       Meta.ZOOM_IN,
                                       Meta.ZOOM_OUT,
                                       Meta.ZOOM_OUT_FURTHER,
                                       Meta.JUMP_TO_CHOOSER,
                                       Meta.JUMP_SHORTCUT,
                                       Meta.CHARGER_CONNECTED,
                                       Meta.CHARGER_DISCONNECTED,
                                       Meta.USB_CONNECTED,
                                       Meta.USB_DISCONNECTED,
                                       Meta.LOW_BATTERY,
                                       Meta.BATTERY_FAILURE_IMMINENT,
                                       Meta.LID_OPEN,
                                       Meta.LID_CLOSE,
                                       Meta.CALL_BUSY,
                                       Meta.CALL_WAITING,
                                       Meta.CALL_ENDED,
                                       Meta.ATTEMPT_CALL,
                                       Meta.CALL_DROPPED,
                                       Meta.CALL_REORDER,
                                       Meta.MENU_ACTIVATION,
                                       Meta.MENU_DISMISS,
                                       Meta.MENU_SHORTCUT,
                                       Meta.DIALOG_OPEN,
                                       Meta.DELETE_ITEM,
                                       Meta.DELETE_TRASH,
                                       Meta.FEEDBACK_NETWORK_X,
                                       Meta.FEEDBACK_NETWORK_PHONEONLY,
                                       Meta.FEEDBACK_NETWORK_1,
                                       Meta.FEEDBACK_NETWORK_2,
                                       Meta.FEEDBACK_NETWORK_3,
                                       Meta.FEEDBACK_NETWORK_G,
                                       Meta.DEFAULT_FOREGROUND,
                                       Meta.DEFAULT_BACKGROUND,
                                       Meta.SYSTEM_FOREGROUND,
                                       Meta.SYSTEM_BACKGROUND,
                                       Meta.APP_SMS_RECEIVED};

    private static final byte[] metaFolderIndex = {0, //"Beep Command Accepted",
                                              0, //"Beep Command Rejected",
                                              0, //"Beep Action Success",
                                              0, //"Beep Action Fail",
                                              0, //"Beep Startup Sound",
                                              1, //"Scroll Limit",
                                              1, //"Scroll Wheel Up",
                                              1, //"Scroll Wheel Down",
                                              1, //"Feedback Wheel Button",
                                              2, //"Feedback Menu Button",
                                              2, //"Feedback Jump Button",
                                              2, //"Feedback Back Button",
                                              2, //"Feedback Key Once",
                                              2, //"Feedback Key Repeat",
                                              2, //"Feedback Delete Key Once",
                                              2, //"Feedback Delete Key Repeat",
                                              2, //"Feedback Return Key Once",
                                              2, //"Feedback Return Key Repeat",
                                              2, //"Feedback Space Key Once",
                                              2, //"Feedback Space Key Repeat",
                                              2, //"Feedback Page Up",
                                              2, //"Feedback Page Down",
                                              2, //"Feedback Auto Replace",
                                              2, //"Feedback Auto Caps",
                                              3, //"Feedback Profile Volume",
                                              3, //"Zoom In",
                                              3, //"Zoom Out",
                                              3, //"Zoom Out Further",
                                              3, //"Jump To Chooser",
                                              3, //"Jump Shortcut",
                                              3, //"Charger Connected",
                                              3, //"Charger Disconnected",
                                              3, //"USB Connected",
                                              3, //"USB Disconnected",
                                              3, //"Low Battery",
                                              3, //"Battery Failure Imminent",
                                              3, //"Lid Open",
                                              3, //"Lid Close",
                                              4, //"Call Busy",
                                              4, //"Call Waiting",
                                              4, //"Call Ended",
                                              4, //"Attempt Call",
                                              4, //"Call Dropped",
                                              4, //"Call Reorder",
                                              5, //"Menu Activation",
                                              5, //"Menu Dismiss",
                                              5, //"Menu Shortcut",
                                              6, //"Dialog Open",
                                              7, //"Delete Item",
                                              7, //"Delete Trash",
                                              8, //"Feedback Network X",
                                              8, //"Feedback Network Phone Only",
                                              8, //"Feedback Network 1 Dot",
                                              8, //"Feedback Network 2 Dots",
                                              8, //"Feedback Network 3 Dots",
                                              8, //"Feedback Network G",
                                              9, //"Default Foreground",
                                              9, //"Default Background",
                                              9, //"System Foreground",
                                              9, //"System Background",
                                              9}; //"Default SMS Ring"}

}