/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.ui.*;
import danger.audio.Tone;
import danger.audio.ToneFilter;
import danger.audio.Meta;
import danger.app.Application;
import danger.app.Event;
import danger.app.ResourceDatabase;
import danger.util.DEBUG;

/**
 * Created by IntelliJ IDEA.
 * User: Jake
 * Date: Dec 13, 2003
 * Time: 8:11:40 PM
 * To change this template use Options | File Templates.
 */
public class MetaPropertiesDialog extends DialogWindow implements Resources, Commands {

    int _metaID;
    Slider    _sldVolume;
    CheckBox  _chkLoop;

    public MetaPropertiesDialog() {
        //default constructor needed
    }

    public void onDecoded() {
        _sldVolume = (Slider)this.getChildWithID(sldMPVolume);
        _chkLoop = (CheckBox)this.getChildWithID(chkMPLoop);

        ResourceDatabase rsrc = Application.getCurrentApp().getResources();
        Bitmap[] volumeIcons = rsrc.getBitmapArray(bmpsVolume);
        Bitmap[] speedIcons = rsrc.getBitmapArray(bmpsSpeed);
        Bitmap[] priorityIcons = rsrc.getBitmapArray(bmpsPriority);

        _sldVolume.setBitmaps(volumeIcons);
        _sldVolume.setSliderType(Slider.COMPRESSED);
        _sldVolume.setTitleSpacing(0);
        _sldVolume.setWidth(100);
    }

    public void setMetaID(int metaID) {
        _metaID = metaID;
        Tone tone = Meta.getToneFromID(metaID);
        if (Meta.isIDMuted(metaID))
            _sldVolume.setValue(0);
        else
            _sldVolume.setValue(Meta.getVolume(metaID));

        if (tone != null)
             _chkLoop.setValue(tone.getLoop()?1:0);
    }

    public boolean receiveEvent(Event event) {
        boolean handled = false;
        switch (event.type) {
            case evtMPDone:
                int vol = _sldVolume.getValue();

                if (vol > 0 && Meta.isIDMuted(_metaID)) Meta.unmuteID(_metaID);

                Tone tone = Meta.getToneFromID(_metaID);
                if (tone != null)
                    tone.setVolume(_sldVolume.getValue());

                //Set loop
                boolean loop = _chkLoop.getValue() != 0;
                Meta.setLoop(_metaID, loop);

                break;
        }
        return handled | super.receiveEvent(event);
    }

    public static MetaPropertiesDialog newMetaPropertiesDialog(int metaID) {
        MetaPropertiesDialog dialog = (MetaPropertiesDialog)Application.getCurrentApp().getResources().getDialog(dlgMetaProperties);
        dialog.setMetaID(metaID);
        return dialog;
    }
}
