/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.ui.ScreenWindow;
import danger.ui.TextField;
import danger.ui.TextInputAlertWindow;
import danger.ui.Menu;
import danger.app.Event;
import danger.app.ResourceDatabase;
import danger.app.IPCMessage;
import danger.app.EventType;
import danger.util.Folder;
import danger.util.DEBUG;
import danger.audio.Tone;
import danger.audio.Meta;
import danger.audio.ToneGallery;
import danger.audio.ToneOrigin;
import danger.audio.ToneRights;

import java.util.Vector;
import java.util.Enumeration;

public class MyTonesWindow extends ScreenWindow implements Resources, Commands, AppEvents {

    private   Penfold        _app;
    protected ToneFolderView _tonesList;

    public MyTonesWindow() {

        _app = (Penfold)this.getApplication();
        setIcon(_app.getBundle().getSmallIcon());

    }

    public void onDecoded() {
        _tonesList = (ToneFolderView)this.getChildWithID(fvwToneList);
    }

    public boolean receiveEvent(Event event) {
        boolean handled = false;

        int cFolderNdx = _tonesList.getCurrentFolderIndex();
        Folder cFolder = _tonesList.getFolder(cFolderNdx);
        Object selected = _tonesList.getSelection();
        switch (event.type) {
            case evtAddTone:
                //showURLDialog("Add Tone from URL", "", evtDoAddTone);
                Event evt = new Event(this, evtDoAddTone);
                AddToneDialog atd = AddToneDialog.newAddToneDialog(evt);
                atd.show();
                break;

            case evtDoAddTone:
                if (cFolder == null) {
                    _tonesList.addFolder(new Folder("My Tones"));
                    cFolder = _tonesList.getFolder("My Tones");
                    cFolder.setOpen(true);
                }
                //String url = TextInputAlertWindow.getTextFieldValue((IPCMessage)event.argument, txtFolderName);
                ToneProperties props = (ToneProperties)event.argument;
                String url = props._url;
                DEBUG.p("Loading " + url);
                HTTPRequest.get(cFolder.getTitle(), props);
                break;

            case evtNewFolder:
                showFolderDialog("Create Folder", "", evtDoCreateFolder);
                break;

            case evtDoCreateFolder:
                Folder nFolder = new Folder(TextInputAlertWindow.getTextFieldValue((IPCMessage)event.argument, txtFolderName));
                nFolder.setOpen(true);
                _tonesList.addFolder(nFolder);
                break;

            case evtRenameFolder:
                if (cFolderNdx < 0) break;
                String cFolderName = cFolder.getTitle();
                showFolderDialog("Rename Folder", cFolderName, evtDoRenameFolder);
                break;

            case evtDoRenameFolder:
                cFolder.setTitle(TextInputAlertWindow.getTextFieldValue((IPCMessage)event.argument, txtFolderName));
                break;

            case evtDelete:
                if (selected instanceof MyTone) {
                    MyTone tone = (MyTone)selected;
                    cFolder.removeItem(tone);
                    destroyTone(tone);
                } else {
                    Folder folder = (Folder)selected;
                    for (int x=0; x<folder.size(); x++) {
                        MyTone item = (MyTone)folder.getItem(x);
                        folder.removeItem(item);
                        destroyTone(item);
                    }
                    _tonesList.removeFolder(folder.getTitle());
                }
                break;

            case evtToneProperties:
                if (selected instanceof MyTone) {
                    TonePropertiesDialog d = TonePropertiesDialog.newTonePropertiesDialog((MyTone)selected);
                    d.show();
                }
                break;

            case evtToneFlags:
                if (selected instanceof MyTone) {
                    ToneFlagsDialog d = ToneFlagsDialog.newToneFlagsDialog((MyTone)selected);
                    d.show();
                }
                break;

            case evtMTDone:
                this.hide();
                break;

            case evtMoveToFolder:
                Event e = new Event(this, evtDoMoveToFolder);
                Vector folders = _tonesList.getFolders();
                String[]  folderNames = new String[folders.size()];
                for (int x=0; x<folders.size(); x++)
                    folderNames[x] = ((Folder)folders.elementAt(x)).getTitle();
                FolderSelectDialog dialog = FolderSelectDialog.newFolderSelectDialog(e, folderNames);
                dialog.show();
                break;

            case evtDoMoveToFolder:
                if (selected instanceof MyTone) {
                    String destFolder = (String)event.argument;
                    cFolder.removeItem(selected);
                    _tonesList.getFolder(destFolder).addItem(selected);
                }

            case evtPreviewTone:
                if (selected instanceof MyTone) {
                    //TonePreviewDialog tp = TonePreviewDialog.newTonePreviewDialog((Tone)selected);
                    //tp.show();
                    _app.previewTone(((MyTone)selected).getTone());
                }
                break;

/*          // commented because no way to add a Tone object to the gallery.
            case evtSetAsRingtone:
                if (selected instanceof Tone) {
                    DEBUG.p("Registering " + ((Tone)selected).getName());
                    int err = ToneGallery.register((Tone)selected);

                    if (err == ToneGallery.Errors.OK)
                        DEBUG.p("Error.OK");
                    else if (err == ToneGallery.Errors.DUPLICATE_ID)
                        DEBUG.p("Error Duplicate OK");
                    else if (err == ToneGallery.Errors.NOT_SETUP)
                        DEBUG.p("Error Not Setup");
                    else
                        DEBUG.p("Error: " + err);

                }
                break;
*/
            case evtAbout:
                _app.showAbout();
                break;
        }
        return handled = super.receiveEvent(event);
    }

    public boolean eventWidgetDown(int i, Event event) {
        boolean handled = false;
        switch (event.what) {
            case EventType.DEVICE_BUTTON_BACK:
                this.hide();
                break;

            case EventType.DEVICE_BUTTON_MENU:
                Object selected = _tonesList.getSelection();
                Menu menu = this.getActionMenu();
                ResourceDatabase rsrc = _app.getResources();
                menu.removeAllItems();

                if (selected == null) {
                    menu.addFromResource(rsrc, mnuMyTonesNone, this);
                } else if (selected instanceof Folder) {
                    menu.addFromResource(rsrc, mnuMyTonesFolder, this);
                } else {
                    menu.addFromResource(rsrc, mnuMyTonesTone, this);
                }
        }
        return super.eventWidgetDown(i, event);
    }

    private void showFolderDialog(String title, String defaultText, int eventToSend) {
        ResourceDatabase rdb = getApplication().getResources();
        TextInputAlertWindow textInput = rdb.getTextInputAlert(rsrcFolderInputWindow, this);
        textInput.setTitle(title);

        textInput.setEventForControlWithID(btnFolderDone, new Event(eventToSend));
        textInput.disableButtonOnEmptyField(btnFolderDone, txtFolderName);
        textInput.setTextField(txtFolderName, defaultText);

        textInput.show();

        // Must be done after show() for some reason.
        ((TextField)textInput.getTextFieldWithID(txtFolderName)).selectAll();
    }

    private void showURLDialog(String title, String defaultText, int eventToSend) {
        ResourceDatabase rdb = getApplication().getResources();
        TextInputAlertWindow textInput = rdb.getTextInputAlert(rsrcURLInputWindow, this);
        textInput.setTitle(title);

        textInput.setEventForControlWithID(btnURLDone, new Event(eventToSend));
        textInput.disableButtonOnEmptyField(btnURLDone, txtURL);
        textInput.setTextField(txtURL, defaultText);

        textInput.show();

        // Must be done after show() for some reason.
        ((TextField)textInput.getTextFieldWithID(txtURL)).selectAll();
    }

    public void addTone(MyTone tone, String folderName) {
        Folder folder = _tonesList.getFolder(folderName);

        if (folder == null) {
            folder = new Folder(folderName);
            _tonesList.addFolder(folder);
        }

        folder.addItem(tone);
        _tonesList.invalidate();
    }

    private void destroyTone(MyTone tone) {
        int toneResID = tone.getTone().getResourceID();

        for (int x=0; x<MetaMeta.getMetaCount(); x++) {
            int metaID = MetaMeta.getMetaID(x);
            Tone metaTone = Meta.getToneFromID(metaID);

            int metaRsrcID = 0;
            if (metaTone != null)
                metaRsrcID = metaTone.getResourceID();

            if (metaRsrcID != 0 && metaRsrcID == toneResID) {
                //DEBUG.p("Tone " + toneResID + " used for meta " + metaID);
                Meta.restoreIDToDefault(metaID);
            }

            //Ringtone function disabled
            //if (tone.isRingtone()) {
            //    ToneGallery.remove(tone);
            //    DEBUG.p("Removed from ToneGallery.");
            //}

        }
        tone.getTone().destroy();
        _tonesList.invalidate();
    }

    public int getToneCount() {
        int count = 0;
        Vector folders = _tonesList.getFolders();
        for (int x=0; x<folders.size(); x++)
            count += ((Folder)folders.elementAt(x)).size();
        return count;
    }

    public int clearTones() {
        int count = 0;
        Vector folders = _tonesList.getFolders();
        for (int x=0; x<folders.size(); x++) {
            Folder fldr = (Folder)folders.elementAt(x);
            for (int y=0; y<fldr.size(); y++) {
                destroyTone((MyTone)fldr.getItem(y));
            }
            fldr.removeAllItems();
        }
        return count;
    }
}
