/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

// Copyright (c) 2003 Jake Bordens
//

package com.wryspy.penfold;


// Import statements.  Add any other packages you might need:
// import danger.audio.*;
// import danger.crypto.*;
// import danger.net.*;
// import danger.ui.*;
// import danger.util.*;
import danger.app.*;
import danger.util.DEBUG;
import danger.ui.*;
import danger.net.HTTPTransaction;
import danger.net.URL;
import danger.net.HiptopConnection;
import danger.audio.*;
import danger.crypto.MD5;


// This is the main application class.  It serves as the entry point
// into your application.  You probably want to rename this class.
// Don't forget to change the constructor name, as well as the file
// name of this source code file.
public class Penfold extends Application implements Commands, Resources {

    public static final int DEFAULT_PRIORITY = 100;
    public static final int DEFAULT_VOLUME   = 100;

    private static TonePreviewDialog tonePreviewDialog;

    static protected MainWindow    mainWindow;
    static protected MyTonesWindow tonesWindow;

	public Penfold() {
        MetaMeta.initalize();

		//Constructor
        mainWindow = (MainWindow)this.getResources().getScreen(scrnMainWindow);
        tonesWindow = (MyTonesWindow)this.getResources().getScreen(scrnMyTonesWindow);

        Registrar.registerProvider("MyTone", this, 1);
	}

    public final void networkEvent(Object s) {
        if (s instanceof HTTPTransaction) {
            HTTPTransaction  t = (HTTPTransaction) s;

            DEBUG.p("Got response " + t.getResponse());

            if (200 == t.getResponse()) {
                byte[]  data = t.getBytes();

                HTTPRequest request = HTTPRequest.pop(t.getSequenceID());

                ToneProperties props = request.getToneProperties();



                //MyTone tone = new MyTone(t.getURL(), data, resID, true, props._loop, props._priority,
                //                 props._volume, props._filter, ToneClass.CUSTOM, name, TONE_GROUP);
                MyTone tone = new MyTone(data, props);
                tone.getTone().setTempo(props._tempo);

                tonesWindow.addTone(tone, request.getFolder());
            } else {
                AlertWindow aw = new AlertWindow(t.getResponseMessage());
                aw.show();
            }
        }
    }


    public boolean receiveEvent(Event event) {
        boolean handled = false;
        switch (event.type) {
            case EventType.EVENT_MESSAGE:
                if (event.what == 1) {
                    DEBUG.p("Got HTConsole Tone!");
                    IPCIncoming m = (IPCIncoming)event.argument;

                    DEBUG.p("Casted to IPCMessage");
                    byte[] data = m.getMessage().findByteArray("usb_data");

                    int resID = ToneGallery.generateResourceID();

                    ToneProperties props = new ToneProperties();
                    props._url = null;
                    props._name = "From HTConsole";

                    MyTone tone = new MyTone(data, props);

                    tonesWindow.addTone(tone, "HTConsole");

                }
        }
        return super.receiveEvent(event);
    }
/*    public boolean receiveEvent(Event event) {
        boolean handled = false;
        switch (event.type) {

            case evtRingtoneFailure:
                String errorMsg;
                switch (event.what) {
                    case ToneGallery.Errors.OK:
                        errorMsg = "Ringtone installed OK";
                        break;

                    case ToneGallery.Errors.MAX_STORED_REACHED:
                        errorMsg = "Maximum number of ringtones installed.";
                        break;

                    case ToneGallery.Errors.BAD_FORMAT:
                        errorMsg = "Unrecognized ringtone format.";
                        break;

                    case ToneGallery.Errors.NOT_FOUND:
                        errorMsg = "Ringtone not found.";
                        break;

                    case ToneGallery.Errors.NOT_SETUP:
                        errorMsg = "Ringtone installation not setup.";
                        break;

                    case ToneGallery.Errors.NULL_OBJECT:
                        errorMsg = "Ringtone object not found.";
                        break;

                    case ToneGallery.Errors.OBJECT_TOO_LARGE:
                        errorMsg = "Ringtone object too large.";
                        break;

                    case ToneGallery.Errors.DUPLICATE_ID:
                        errorMsg = "Duplicate ringtone ID.";
                        break;

                    case ToneGallery.Errors.DELETE_CANCELED:
                        errorMsg = "Delete operation canceled.";
                        break;

                    default:
                        errorMsg = "Unknown ringtone installation error";
                }
                AlertWindow a = new AlertWindow(errorMsg);
                a.show();

                break;
        }
        return handled || super.receiveEvent(event);
    }
  */

    public FolderView getTonesList() {
        return tonesWindow._tonesList;
    }

    public void clearAllMyTones() {
        tonesWindow.clearTones();
    }

    public void openURL(URL url) {
        DEBUG.p(url.toString());
    }

    public void showAbout() {
        AlertWindow about = getResources().getAlert(alrtAboutPenfold);
        about.show();
    }

    public void previewTone(Tone tone) {
        if (tonePreviewDialog != null)
            stopPreview();

        if (tone != null) {
            tonePreviewDialog = TonePreviewDialog.newTonePreviewDialog(tone);
            tonePreviewDialog.show();
        }
    }

    public void stopPreview() {
        tonePreviewDialog.stop();
        tonePreviewDialog.hide();
        tonePreviewDialog = null;
    }

    public void suspend() {
        stopPreview();
    }

    public void resume() {

        //DEBUG.p("Time: " + System.currentTimeMillis());
/*
        long expireTime =  1073870828033L + (1000 * 60 * 60 * 24 * 15);

        if (System.currentTimeMillis() >= expireTime) {
            AlertWindow w = new AlertWindow("Application Expired",
                    "This application has expired.\n" +
                    "Please contact Jake for more info.", false, AlertWindow.SYSTEM_ERROR_STYLE);
            MetaMeta.resetMetas();
            this.returnToLauncher();

            tonesWindow.clearTones();
            w.show();

            return;
        }
*/
        mainWindow.show();

        /*

        String userName = HiptopConnection.getUserName().toLowerCase();
        byte[] userHash = {124, 23, 118, 91, 46, 100, 121, -9, 55, 47, 101, 69, -80, -62, -39, 72};

        MD5 hasher = new MD5();
        hasher.update(userName.getBytes());
        byte[] hash = hasher.digest();

        boolean allowed = true;
        for (int x=0; x<hash.length; x++)
            if (hash[x] != userHash[x]) allowed=false;

        if (!allowed) {
            AlertWindow w = new AlertWindow("Application Locked",
                    "You are not authorized to run this app", false, AlertWindow.SYSTEM_ERROR_STYLE);
            this.returnToLauncher();
            w.show();
            return;
        }

        if (System.currentTimeMillis() >= expireTime) {
            AlertWindow w = new AlertWindow("Application Expired",
                    "This application has expired", false, AlertWindow.SYSTEM_ERROR_STYLE);
            this.returnToLauncher();
            w.show();
            return;
        }
        mainWindow.show();
          */
    }

    public void quit() {
        DEBUG.p("App asked to quit. Clearing tones.");
        tonesWindow.clearTones();
        super.quit();
    }
}