/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.ui.*;
import danger.audio.Tone;
import danger.audio.ToneFilter;
import danger.audio.ToneClass;
import danger.app.Application;
import danger.app.Event;
import danger.app.ResourceDatabase;
import danger.util.DEBUG;

/**
 * Created by IntelliJ IDEA.
 * User: Jake
 * Date: Dec 13, 2003
 * Time: 8:11:40 PM
 * To change this template use Options | File Templates.
 */
public class ToneFlagsDialog extends DialogWindow implements Resources, Commands {

    Tone _tone;
    CheckBox  _chkForeground;
    CheckBox  _chkBackground;
    CheckBox  _chkSystem;
    CheckBox  _chkKeyPress;

    public ToneFlagsDialog() {
        //default constructor needed
    }

    public void onDecoded() {
        _chkForeground = (CheckBox)this.getChildWithID(chkTFForeground);
        _chkBackground = (CheckBox)this.getChildWithID(chkTFBackground);
        _chkSystem = (CheckBox)this.getChildWithID(chkTFSystem);
        _chkKeyPress = (CheckBox)this.getChildWithID(chkTFKeyClick);
    }

    public void setTone(MyTone tone) {
        _tone = tone.getTone();
        _chkForeground.setValue((_tone.getToneClass() & ToneClass.FOREGROUND) != 0?1:0);
        _chkBackground.setValue((_tone.getToneClass() & ToneClass.BACKGROUND) != 0?1:0);
        _chkSystem.setValue((_tone.getToneClass() & ToneClass.SYSTEM) != 0?1:0);
        _chkKeyPress.setValue((_tone.getToneClass() & ToneClass.KEY) != 0?1:0);
    }

    public boolean receiveEvent(Event event) {
        boolean handled = false;
        switch (event.type) {
            case evtTFDone:
                int toneclass = ToneClass.CUSTOM;
                if (_chkForeground.getValue() != 0) toneclass |= ToneClass.FOREGROUND;
                if (_chkBackground.getValue() != 0) toneclass |= ToneClass.BACKGROUND;
                if (_chkSystem.getValue() != 0) toneclass |= ToneClass.SYSTEM;
                if (_chkKeyPress.getValue() != 0) toneclass |= ToneClass.KEY;
                _tone.setToneClass(toneclass);
                this.hide();
                break;
        }
        return handled | super.receiveEvent(event);
    }

    public static ToneFlagsDialog newToneFlagsDialog(MyTone tone) {
        ToneFlagsDialog dialog = (ToneFlagsDialog)Application.getCurrentApp().getResources().getDialog(dlgToneFlags);
        dialog.setTone(tone);
        return dialog;
    }
}
