/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.ui.*;
import danger.util.Folder;
import danger.util.StringUtils;
import danger.util.DEBUG;
import danger.app.Application;
import danger.app.ResourceDatabase;
//import danger.audio.Tone;
import danger.audio.Sequence;
import danger.audio.Sound;
import com.wryspy.penfold.Resources;
import com.wryspy.penfold.MetaMeta;
import com.wryspy.penfold.MetaObject;


public class ToneFolderView extends FolderView implements Resources {

    private Bitmap[] volumeIcons;
    private Bitmap   wavIcon;
    private Bitmap   midiIcon;

    private final static int VOLUME_ICON_WIDTH = 20;

    public ToneFolderView() {
        //default constructor
    }

    public void onDecoded() {
        // add folders from MetaMeta
        ResourceDatabase rsrc = Application.getCurrentApp().getResources();
        volumeIcons = rsrc.getBitmapArray(bmpsVolume);
        wavIcon = rsrc.getBitmap(bmpWavIcon);
        midiIcon = rsrc.getBitmap(bmpMidiIcon);

    }

    protected void drawFolderLine(Pen pen, Object o, Rect rect, boolean b) {
        Folder  folderToDraw = (Folder)o;
        int textPos = folderToDraw.getOpenIcon().getWidth() + COLUMN_GAP;
        int offset  = rect.left + textPos;

        String  title = folderToDraw.getTitle();
        int             numItemsInFolder = folderToDraw.size();

        title += " (" + numItemsInFolder + ")";

        title = StringUtils.truncate(title, rect.right - offset, mFontBold, StringUtils.TRUNCATE_AT_END);

        pen.setFont(mFontBold);
        pen.drawText(offset, rect.top + mAscent, title);

        if (folderToDraw.isOpen())
            pen.drawBitmap(rect.left, rect.top + 1, folderToDraw.getOpenIcon());
        else
            pen.drawBitmap(rect.left, rect.top + 1, folderToDraw.getClosedIcon());
    }

    protected void drawItemLine(Pen pen, Object o, Rect rect, boolean b) {
        MyTone obj = (MyTone)o;
        String    text = obj.getTone().getName();
        int  offset = rect.left + 10;

        pen.setFont(mFontPlain);

        text = StringUtils.makeDisplayString(text, rect.getWidth(), mFontPlain);

        int vol = obj.getTone().getVolume();

        String mime = obj.getTone().getMimeType();

        if (mime.equalsIgnoreCase("audio/midi") || mime.equalsIgnoreCase("audio/rmf")) {
            pen.drawBitmap(offset, rect.top + 1, midiIcon);
            offset += midiIcon.getWidth() + 2;
        } else if (mime.equalsIgnoreCase("audio/wav") || mime.equalsIgnoreCase("audio/x-aiff")) {
            pen.drawBitmap(offset, rect.top + 1, wavIcon);
            offset += wavIcon.getWidth() + 2;
        }

        Bitmap toDraw = null;
        if (vol == 0)
            toDraw = volumeIcons[0];
        else
            toDraw = volumeIcons[(vol/50)+1];


        pen.drawBitmap(offset, rect.top + 1, toDraw);
        offset += volumeIcons[0].getWidth() + 2;

        pen.drawText(offset, rect.top + mAscent, text);


    }

    protected void drawEmptyList(Pen pen) {
           super.drawEmptyList(pen);

           Font f = Font.findBoldSystemFont();
           String msg = "No folders or tones in list.";
           int msgWidth = f.getWidth(msg);
           int msgHeight = f.getAscent();
           pen.setFont(f);
           pen.drawText((getWidth() / 2) - (msgWidth / 2),
                        (getHeight() / 2) - (msgHeight /2),
                         msg);
           f = Font.findSystemFont();
           pen.setFont(f);
           msg = "Press \uF007 to add folders or tones.";
           msgWidth = f.getWidth(msg);
           pen.drawText((getWidth() / 2) - (msgWidth / 2),
                        (getHeight() / 2) - (msgHeight /2) + msgHeight,
                         msg);
       }


}
