/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.ui.DialogWindow;
import danger.ui.ProgressBar;
import danger.audio.Tone;
import danger.app.Application;
import danger.app.Timer;
import danger.app.Event;
import danger.app.EventType;

public class TonePreviewDialog extends DialogWindow implements Resources, Commands {

    private ProgressBar _pb;
    private Tone        _tone;
    private Timer       _throb;

    public TonePreviewDialog() {
        //default constructor
    }

    public void onDecoded() {
        _pb = (ProgressBar)this.getChildWithID(pbThrobber);
    }

    public static TonePreviewDialog newTonePreviewDialog(Tone tone) {
        TonePreviewDialog dialog = (TonePreviewDialog)Application.getCurrentApp().getResources().getDialog(dlgTonePreview);
        dialog._tone = tone;
        return dialog;
    }

    public void show() {
        //ToDo: this resets the volume?
        _tone.play(_tone.getVolume());
        _throb = new Timer(500, true, this);
        _throb.start();
        super.show();
    }

    public boolean receiveEvent(Event event) {
        boolean handled = false;

        switch (event.type) {
            case EventType.EVENT_TIMER:
                _pb.advanceState();
                if (!_tone.isDone())
                    break;

            case evtTPDone:
                _throb.stop();
                _tone.stop();
                this.hide();
                break;

        }
        return handled | super.receiveEvent(event);
    }

    public void stop() {
        _tone.stop();
    }

}
