/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.ui.*;
import danger.audio.Tone;
import danger.audio.ToneFilter;
import danger.app.Application;
import danger.app.Event;
import danger.app.ResourceDatabase;
import danger.util.DEBUG;

/**
 * Created by IntelliJ IDEA.
 * User: Jake
 * Date: Dec 13, 2003
 * Time: 8:11:40 PM
 * To change this template use Options | File Templates.
 */
public class TonePropertiesDialog extends DialogWindow implements Resources, Commands {

    Tone _tone;
    TextField _txtName;
    Slider    _sldVolume;
    Slider    _sldPriority;
    Slider    _sldTempo;
    CheckBox  _chkLoop;
    CheckBox  _chkFlash;
    CheckBox  _chkVibrate;

    public TonePropertiesDialog() {
        //default constructor needed
    }

    public void onDecoded() {
        _txtName = (TextField)this.getChildWithID(txtTPName);
        _sldVolume = (Slider)this.getChildWithID(sldTPVolume);
        _sldPriority = (Slider)this.getChildWithID(sldTPPriority);
        _sldTempo = (Slider)this.getChildWithID(sldTPTempo);
        _chkLoop = (CheckBox)this.getChildWithID(chkTPLoop);
        _chkFlash = (CheckBox)this.getChildWithID(chkTPFlash);
        _chkVibrate = (CheckBox)this.getChildWithID(chkTPVibrate);

        ResourceDatabase rsrc = Application.getCurrentApp().getResources();
        Bitmap[] volumeIcons = rsrc.getBitmapArray(bmpsVolume);
        Bitmap[] speedIcons = rsrc.getBitmapArray(bmpsSpeed);
        Bitmap[] priorityIcons = rsrc.getBitmapArray(bmpsPriority);

        _sldVolume.setBitmaps(volumeIcons);
        _sldVolume.setSliderType(Slider.COMPRESSED);
        _sldVolume.setTitleSpacing(0);
        _sldVolume.setWidth(100);

        _sldPriority.setBitmaps(priorityIcons);
        _sldPriority.setSliderType(Slider.COMPRESSED);
        _sldPriority.setTitleSpacing(0);
        _sldPriority.setWidth(100);

        _sldTempo.setBitmaps(speedIcons);
        _sldTempo.setSliderType(Slider.COMPRESSED);
        _sldTempo.setTitleSpacing(0);
        _sldTempo.setWidth(100);

        _chkFlash.setEnabled(false);
        _chkVibrate.setEnabled(false);
    }

    public void setTone(MyTone tone) {
        String mime;

        _tone = tone.getTone();
        mime = _tone.getMimeType();
        _txtName.setText(_tone.getName());
        _sldVolume.setValue(_tone.getVolume());
        _sldPriority.setValue(_tone.getPriority());
        _sldTempo.setValue(_tone.getTempo());
        _chkLoop.setValue(_tone.getLoop()?1:0);
        _chkFlash.setValue((_tone.getPlaybackFilter() & ToneFilter.FLASHER)!=0?1:0);
        _chkVibrate.setValue((_tone.getPlaybackFilter() & ToneFilter.BUZZER)!=0?1:0);
        if (mime.equalsIgnoreCase("audio/midi") || mime.equalsIgnoreCase("audio/rmf"))
            _sldTempo.enable();
        else
            _sldTempo.disable();
    }

    public boolean receiveEvent(Event event) {
        boolean handled = false;
        switch (event.type) {
            case evtTPDone:
                _tone.setName(_txtName.toString());
                _tone.setVolume(_sldVolume.getValue());
                _tone.setPriority(_sldPriority.getValue());
                _tone.setTempo(_sldTempo.getValue());
                _tone.setLoop(_chkLoop.getValue() == 1);

                break;
        }
        return handled | super.receiveEvent(event);
    }

    public static TonePropertiesDialog newTonePropertiesDialog(MyTone tone) {
        TonePropertiesDialog dialog = (TonePropertiesDialog)Application.getCurrentApp().getResources().getDialog(dlgToneProperties);
        dialog.setTone(tone);
        return dialog;
    }
}
