/*
 * Copyright (C) 2003 Jake Bordens.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 *
 * 
 *  This file is part of
 *        Penfold - sound mapper for Danger Hiptop
 *
 */

package com.wryspy.penfold;

import danger.app.Listener;
import danger.app.Event;
import danger.app.Application;
import danger.ui.*;
import danger.util.DEBUG;
import danger.util.Folder;
import danger.audio.Tone;

import java.util.Vector;

public class ToneSelectDialog extends DialogWindow implements Commands, Resources, AppEvents {

    Tone _tone;
    Event _event;
    Menu _popup;
    Button _button;

    public ToneSelectDialog() {
        //default constructor for rsrc
        _popup = new Menu("My Tones", true);
        _popup.setWindow(this);
        _popup.setShowTitle(false);
        _popup.centerOnParentWindow(true);
    }

    public void onDecoded() {
        //_popup = (PopupMenu)this.getChildWithID(popTSTone);
        _button = (Button)this.getChildWithID(btnTSTone);
    }

    public boolean receiveEvent(Event event) {
        boolean handled = false;
        switch (event.type) {
            case evtPickedTone:
                _tone = (Tone)event.argument;
                if (_tone != null)
                    _button.setTitle(_tone.getName());
                else
                    _button.setTitle("Default Tone");
                break;

            case evtTSDone:
                MenuItem i = _popup.getItem(_popup.getValue());
                _event.argument = _tone;
                _event.sendToTarget();
                this.hide();
                break;

            case evtTSTone:
                _popup.enterMenu();
                break;
        }
        return super.receiveEvent(event);
    }

    public static ToneSelectDialog newToneSelectDialog(Event evt, FolderView fv) {
        ToneSelectDialog dialog = (ToneSelectDialog)Application.getCurrentApp().getResources().getDialog(dlgToneSelect);
        dialog._event = evt;
        dialog._popup.addItem("Default Tone", evtPickedTone, 0, null, dialog);
        Vector folders = fv.getFolders();
        for (int x=0; x<folders.size(); x++) {
            Folder folder = (Folder)folders.elementAt(x);
            Menu folderMenu = new Menu(folder.getTitle());
            for (int y=0; y<folder.size(); y++) {
                Tone tone = ((MyTone)folder.getItem(y)).getTone();
                folderMenu.addItem(tone.getName(), evtPickedTone, 0, tone, dialog);
            }
            MenuItem thisItem = new MenuItem(folder.getTitle());
            //folderMenu.setSubmenu(true);
            thisItem.addSubMenu(folderMenu);
            dialog._popup.addItem(thisItem);
        }

        return dialog;
    }

}
